/* Seven Segment Optical Character Recognition */

/*  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/* Copyright (C) 2004-2023 Erik Auerswald <auerswal@unix-ag.uni-kl.de> */

#ifndef SSOCR2_H
#define SSOCR2_H

typedef struct {
  int x1,y1,x2,y2,digit,spaces;
} digit_struct;

typedef struct {
  int R, G, B, A;
} color_struct;

typedef struct {
  int w, h;
} dimensions_struct;

typedef struct {
  int min, max;
} interval_struct;

#endif /* SSOCR2_H */
